@@ -45,8 +45,13 @@ def track_frames_sp(opts,
             frames = np.array(
                 [image.get_processed_frame(np.double(readers[iC].get_data(fr))) for iC in range(len(videos))])
         else:
-            frames = np.array(
-                [image.get_processed_frame(np.double(readers[iC].get_data(opts['frame_maps'][iC][fr]))) for iC in range(len(videos))])
+            frames = []
+            for iC in range(len(videos)):
+                frame_idx = opts['frame_maps'][iC][fr]
+                if frame_idx<0:
+                    frames.append(image.get_processed_frame(np.double(np.zeros(shape=readers[iC].get_data(0).shape))))
+                else:
+                    frames.append(image.get_processed_frame(np.double(readers[iC].get_data(frame_idx))))
 
         # print(f'{fr} {time.time()} compute minima')
         minima = [np.flip(image.get_minima(frames[iC], opts['led_thres']), axis=1) for iC in
